@@ -134,7 +134,7 @@ def _prepare_anki_note_fields(note: Dict, last_note: 'AnkiCard', assets: MediaAs
     if game_name_field := config.anki.game_name_field:
         note['fields'][game_name_field] = get_current_game()
 
-    if config.ai.enabled:
+    if config.ai.add_to_anki:
         sentence_field = note['fields'].get(config.anki.sentence_field, {})
         sentence_to_translate = sentence_field or last_note.get_field(config.anki.sentence_field)
         translation = get_ai_prompt_result(get_all_lines(), sentence_to_translate, game_line, get_current_game())
@@ -233,12 +233,16 @@ def update_anki_card(last_note: 'AnkiCard', note=None, audio_path='', video_path
         config_app: 'ConfigApp' = gsm_state.config_app
         sentence = note['fields'].get(config.anki.sentence_field, last_note.get_field(config.anki.sentence_field))
         
-        use_voice, sentence, translation, new_ss_path = config_app.show_anki_confirmation_dialog(
-            tango, sentence, assets.screenshot_path, assets.audio_path, translation, ss_time
+        use_voice, sentence, translation, new_ss_path, add_nsfw_tag = config_app.show_anki_confirmation_dialog(
+            tango, sentence, assets.screenshot_path, assets.audio_path if update_audio_flag else None, translation, ss_time
         )
         note['fields'][config.anki.sentence_field] = sentence
         note['fields'][config.ai.anki_field] = translation
         assets.screenshot_path = new_ss_path or assets.screenshot_path
+        
+        # Add NSFW tag if checkbox was selected
+        if add_nsfw_tag:
+            tags.append("NSFW")
 
     # 5. If creating new media, store files in Anki's collection. Then update note fields.
     if not use_existing_files:
@@ -279,7 +283,8 @@ def update_anki_card(last_note: 'AnkiCard', note=None, audio_path='', video_path
             sentence_in_anki=game_line.text if game_line else '',
             multi_line=bool(selected_lines and len(selected_lines) > 1),
             video_in_anki=assets.video_in_anki or '',
-            word_path=word_path
+            word_path=word_path,
+            word=tango
         )
     
     # 9. Update the local application database with final paths
@@ -554,14 +559,17 @@ def update_new_card():
     else:
         logger.info("New card(s) detected! Added to Processing Queue!")
         gsm_state.last_mined_line = game_line
-        card_queue.append((last_card, datetime.now(), lines))
-        texthooking_page.reset_checked_lines()
-        try:
-            obs.save_replay_buffer()
-        except Exception as e:
-            card_queue.pop(0)
-            logger.error(f"Error saving replay buffer: {e}")
-            return
+        queue_card_for_processing(last_card, lines)
+        
+def queue_card_for_processing(last_card, lines):
+    card_queue.append((last_card, datetime.now(), lines))
+    texthooking_page.reset_checked_lines()
+    try:
+        obs.save_replay_buffer()
+    except Exception as e:
+        card_queue.pop(0)
+        logger.error(f"Error saving replay buffer: {e}")
+        return
 
 def update_card_from_same_sentence(last_card, lines, game_line):
     time_elapsed = 0
@@ -570,16 +578,15 @@ def update_card_from_same_sentence(last_card, lines, game_line):
         time_elapsed += 0.5
         if time_elapsed > 15:
             logger.info(f"Timed out waiting for Anki update for card {last_card.noteId}, retrieving new audio")
-            card_queue.append((last_card, datetime.now(), lines))
-            texthooking_page.reset_checked_lines()
-            try:
-                obs.save_replay_buffer()
-            except Exception as e:
-                card_queue.pop(0)
-                logger.error(f"Error saving replay buffer: {e}")
-                return
+            queue_card_for_processing(last_card, lines)
             return
     anki_result = anki_results[game_line.id]
+    
+    if anki_result.word == last_card.get_field(get_config().anki.word_field):
+        logger.info(f"Same word detected, attempting to get new audio for card {last_card.noteId}")
+        queue_card_for_processing(last_card, lines)
+        return
+    
     if anki_result.success:
         note, last_card = get_initial_card_info(last_card, lines)
         tango = last_card.get_field(get_config().anki.word_field)
@@ -640,59 +647,10 @@ def start_monitoring_anki():
     obs_thread.start()
 
 
-# --- Anki Stats Kanji Extraction Utilities ---
+# --- Anki Stats Utilities ---
+# Note: Individual query functions have been removed in favor of the combined endpoint
+# All Anki statistics are now fetched through /api/anki_stats_combined
 
-def get_anki_earliest_date():
-    """
-    Fetches the earliest Anki card ID.
-    """
-    try:
-        note_ids = invoke("findCards", query="")
-        if not note_ids:
-            return 0
-        
-        # Return the first card ID as the "earliest"
-        # return note_ids[0]
-        return min(note_ids)
-        
-    except Exception as e:
-        logger.error(f"Failed to fetch kanji from Anki: {e}")
-        return 0
-
-def get_all_anki_first_field_kanji(start_timestamp = None, end_timestamp = None):
-    """
-    Fetch all notes from Anki and extract unique kanji from the first field of each note.
-    Returns a set of kanji characters.
-    Optional filtering by start_timestamp and end_timestamp on note IDs.
-    """
-    from GameSentenceMiner.web.stats import is_kanji
-    try:
-        note_ids = invoke("findNotes", query="")
-        if not note_ids:
-            return set()
-        
-        # Filter note IDs by start and end timestamps if provided
-        if (start_timestamp and end_timestamp):
-            note_ids = [nid for nid in note_ids if int(start_timestamp) <= nid <= int(end_timestamp)]
-            if not note_ids:
-                return set()
-        kanji_set = set()
-        batch_size = 1000
-        for i in range(0, len(note_ids), batch_size):
-            batch_ids = note_ids[i:i+batch_size]
-            notes_info = invoke("notesInfo", notes=batch_ids)
-            for note in notes_info:
-                fields = note.get("fields", {})
-                first_field = next(iter(fields.values()), None)
-                if first_field and "value" in first_field:
-                    first_field_value = first_field["value"]
-                    for char in first_field_value:
-                        if is_kanji(char):
-                            kanji_set.add(char)
-        return kanji_set
-    except Exception as e:
-        logger.error(f"Failed to fetch kanji from Anki: {e}")
-        return set()
 
 
 if __name__ == "__main__":
