@@ -1,3 +1,7 @@
+# There should be no imports here, as any error will crash the program.
+# All imports should be done in the try/except block below.
+
+
 def handle_error_in_initialization(e):
     """Handle errors that occur during initialization."""
     logger.exception(e, exc_info=True)
@@ -24,6 +28,7 @@ try:
     import requests
     import os.path
     import signal
+    import datetime
     from subprocess import Popen
     os.environ.pop('TCL_LIBRARY', None)
 
@@ -36,13 +41,17 @@ try:
     import psutil
 
     start_time = time.time()
+    import GameSentenceMiner.util.configuration
     from GameSentenceMiner.util.configuration import logger, gsm_state, get_config, anki_results, AnkiUpdateResult, \
     get_temporary_directory, get_log_path, get_master_config, switch_profile_and_save, get_app_directory, gsm_status, \
-    is_windows, is_linux
-    from GameSentenceMiner.util.get_overlay_coords import OverlayThread
-    from GameSentenceMiner.util.gsm_utils import remove_html_and_cloze_tags
+    is_windows, is_linux, get_ffmpeg_path
 
     logger.debug(f"[Import] configuration: {time.time() - start_time:.3f}s")
+    
+    start_time = time.time()
+    from GameSentenceMiner.util.get_overlay_coords import OverlayThread
+    from GameSentenceMiner.util.gsm_utils import remove_html_and_cloze_tags, add_srt_line
+    logger.debug(f"[Import] get_overlay_coords (OverlayThread, remove_html_and_cloze_tags): {time.time() - start_time:.3f}s")
 
     start_time = time.time()
     from GameSentenceMiner.util.model import VADResult
@@ -72,7 +81,7 @@ try:
     logger.debug(f"[Import] anki: {time.time() - start_time:.3f}s")
 
     start_time = time.time()
-    from GameSentenceMiner import config_gui
+    from GameSentenceMiner.ui import config_gui
     logger.debug(f"[Import] config_gui: {time.time() - start_time:.3f}s")
 
     start_time = time.time()
@@ -98,7 +107,7 @@ try:
         f"[Import] websocket (connect_websocket, register_websocket_message_handler, FunctionName): {time.time() - start_time:.3f}s")
 
     start_time = time.time()
-    from GameSentenceMiner.util.ffmpeg import get_audio_and_trim, get_video_timings, get_ffmpeg_path
+    from GameSentenceMiner.util.ffmpeg import get_audio_and_trim, get_video_timings
     logger.debug(
         f"[Import] util.ffmpeg (get_audio_and_trim, get_video_timings, get_ffmpeg_path): {time.time() - start_time:.3f}s")
 
@@ -145,15 +154,28 @@ class VideoToAudioHandler(FileSystemEventHandler):
         super().__init__()
 
     def on_created(self, event):
-        if event.is_directory or ("Replay" not in event.src_path and "GSM" not in event.src_path):
+        file_name = os.path.basename(event.src_path)
+        if event.is_directory or ("Replay" not in file_name and "GSM" not in file_name):
+            # This shows up as soon as recording starts, so it's kinda hard to use...
+            # if get_config().features.generate_longplay and event.src_path.endswith(".mkv") or event.src_path.endswith(".mp4"):
+            #     add_srt_line(datetime.datetime.now(), get_all_lines()[-1])
+            #     logger.info(f"Recording {event.src_path} FOUND, RUNNING LOGIC")
+            #     wait_for_stable_file(event.src_path)
+            #     current_srt = gsm_state.current_srt
+            #     srt_name = os.path.splitext(os.path.basename(event.src_path))[0] + ".srt"
+            #     srt_path = os.path.join(os.path.dirname(event.src_path), srt_name)
+            #     shutil.move(current_srt, srt_path)
+            #     gsm_state.current_srt = None
+            #     # self.process_replay(event.src_path)
             return
         # Adjust based on your OBS output format
-        if event.src_path.endswith(".mkv") or event.src_path.endswith(".mp4"):
+        if file_name.endswith(".mkv") or file_name.endswith(".mp4"):
             logger.info(f"MKV {event.src_path} FOUND, RUNNING LOGIC")
             wait_for_stable_file(event.src_path)
             self.process_replay(event.src_path)
 
     def process_replay(self, video_path):
+        gsm_state.current_replay = video_path
         vad_trimmed_audio = ''
         final_audio_output = ''
         skip_delete = False
@@ -194,6 +216,7 @@ class VideoToAudioHandler(FileSystemEventHandler):
             # Get Info of line mined
             line_cutoff = None
             start_line = None
+            full_text = ''
             if selected_lines:
                 start_line = selected_lines[0]
                 mined_line = get_mined_line(last_note, selected_lines)
@@ -300,7 +323,7 @@ class VideoToAudioHandler(FileSystemEventHandler):
                                                                 f"{obs.get_current_game(sanitize=True)}.{get_config().audio.extension}"))
 
         vad_result = vad_processor.trim_audio_with_vad(
-            trimmed_audio, vad_trimmed_audio, game_line)
+            trimmed_audio, vad_trimmed_audio, game_line, full_text)
         if timing_only:
             return vad_result
 
@@ -337,7 +360,7 @@ class VideoToAudioHandler(FileSystemEventHandler):
 
 def initial_checks():
     try:
-        subprocess.run(ffmpeg.ffmpeg_base_command_list)
+        subprocess.run(GameSentenceMiner.util.configuration.ffmpeg_base_command_list)
         logger.debug("FFMPEG is installed and accessible.")
     except FileNotFoundError:
         logger.error(
@@ -465,6 +488,13 @@ class GSMTray(threading.Thread):
         self.run_tray()
 
     def run_tray(self):
+        def run_anki_confirmation_window():
+            settings_window.show_anki_confirmation_dialog(expression="こんにちは",
+                sentence="こんにちは、世界！元気ですか？",
+                screenshot_path="test_image.png",
+                audio_path="C:/path/to/my/audio.mp3",
+                translation="Hello world! How are you?")
+
         self.profile_menu = Menu(
             *[MenuItem(("Active: " if profile == get_master_config().current_profile else "") + profile, self.switch_profile) for
               profile in
@@ -478,9 +508,10 @@ class GSMTray(threading.Thread):
             MenuItem("Toggle Replay Buffer", self.play_pause),
             MenuItem("Restart OBS", restart_obs),
             MenuItem("Switch Profile", self.profile_menu),
+            MenuItem("Run Test Code", run_anki_confirmation_window),
             MenuItem("Exit", exit_program)
         )
-
+        
         self.icon = Icon("TrayApp", create_image(), "GameSentenceMiner", menu)
         self.icon.run()
 
@@ -574,6 +605,8 @@ def restart_obs():
 
 def cleanup():
     try:
+        if gsm_state.current_srt and len(get_all_lines()) > 0:
+            add_srt_line(datetime.datetime.now(), get_all_lines()[-1])
         logger.info("Performing cleanup...")
         gsm_state.keep_running = False
 
@@ -794,6 +827,7 @@ async def async_main(reloading=False):
         root = ttk.Window(themename='darkly')
         start_time = time.time()
         settings_window = config_gui.ConfigApp(root)
+        gsm_state.config_app = settings_window
         initialize_async()
         observer = Observer()
         observer.schedule(VideoToAudioHandler(),
@@ -823,6 +857,11 @@ async def async_main(reloading=False):
             if get_config().general.open_config_on_startup:
                 root.after(50, settings_window.show)
             root.after(50, gsm_tray.start)
+            # root.after(100, settings_window.show_anki_confirmation_dialog(expression="こんにちは",
+            #     sentence="こんにちは、世界！元気ですか？",
+            #     screenshot_path="test_image.png",
+            #     audio_path="C:/path/to/my/audio.mp3",
+            #     translation="Hello world! How are you?"))
             settings_window.add_save_hook(gsm_tray.update_icon)
             settings_window.on_exit = exit_program
             root.mainloop()
