@@ -5,6 +5,7 @@ import os
 import shutil
 import threading
 import inspect
+import re
 
 from dataclasses import dataclass, field
 from logging.handlers import RotatingFileHandler
@@ -409,7 +410,6 @@ class General:
         except ValueError:
             return "Unknown"
 
-
 @dataclass_json
 @dataclass
 class Paths:
@@ -424,9 +424,11 @@ class Paths:
 
     def __post_init__(self):
         if self.folder_to_watch:
-            self.folder_to_watch = os.path.normpath(self.folder_to_watch)
+            self.folder_to_watch = os.path.normpath(self.folder_to_watch).replace("\\", "/")
+            self.folder_to_watch = re.sub(r'/+', '/', self.folder_to_watch)
         if self.output_folder:
-            self.output_folder = os.path.normpath(self.output_folder)
+            self.output_folder = os.path.normpath(self.output_folder).replace("\\", "/")
+            self.output_folder = re.sub(r'/+', '/', self.output_folder)
 
 
 @dataclass_json
@@ -617,6 +619,7 @@ class Advanced:
 @dataclass
 class Ai:
     enabled: bool = False
+    add_to_anki: bool = False
     anki_field: str = ''
     provider: str = AI_GEMINI
     gemini_model: str = 'gemini-2.5-flash-lite'
@@ -643,10 +646,22 @@ class Ai:
             self.gemini_model = 'gemini-2.5-flash-lite'
         if self.groq_model in ['RECOMMENDED', 'OTHER']:
             self.groq_model = 'meta-llama/llama-4-scout-17b-16e-instruct'
+            
+        if self.enabled:
+            self.add_to_anki = True
 
         # Change Legacy Model Name
         if self.gemini_model == 'gemini-2.5-flash-lite-preview-06-17':
             self.gemini_model = 'gemini-2.5-flash-lite'
+            
+    def is_configured(self) -> bool:
+        if self.provider == AI_GEMINI and self.gemini_api_key and self.gemini_model:
+            return True
+        if self.provider == AI_GROQ and self.groq_api_key and self.groq_model:
+            return True
+        if self.provider == AI_OPENAI and self.open_ai_api_key and self.open_ai_model and self.open_ai_url:
+            return True
+        return False
 
 
 class OverlayEngine(str, Enum):
@@ -662,11 +677,22 @@ class Overlay:
     periodic: bool = False
     periodic_interval: float = 1.0
     scan_delay: float = 0.25
+    minimum_character_size: int = 0
 
     def __post_init__(self):
         if self.monitor_to_capture == -1:
             self.monitor_to_capture = 0  # Default to the first monitor if not set
-
+            
+        try:
+            import mss as mss
+            monitors = [f"Monitor {i}: width: {monitor['width']}, height: {monitor['height']}" for i, monitor in enumerate(mss.mss().monitors[1:], start=1)]
+            if len(monitors) == 0:
+                monitors = [1]
+            self.monitors = monitors
+        except ImportError:
+            self.monitors = []
+        if self.monitor_to_capture >= len(self.monitors):
+            self.monitor_to_capture = 0  # Reset to first monitor if out of range
 
 @dataclass_json
 @dataclass
@@ -823,6 +849,7 @@ class Config:
     switch_to_default_if_not_found: bool = True
     locale: str = Locale.English.value
     stats: StatsConfig = field(default_factory=StatsConfig)
+    overlay: Overlay = field(default_factory=Overlay)
     version: str = ""
 
     @classmethod
@@ -861,15 +888,16 @@ class Config:
                 if profile.advanced.streak_requirement_hours != default_stats.streak_requirement_hours:
                     self.stats.streak_requirement_hours = profile.advanced.streak_requirement_hours
         
+        self.overlay = self.get_config().overlay
+        
         # Add a way to migrate certain things based on version if needed, also help with better defaults
         if self.version:
-            if self.version != get_current_version():
+            current_version = get_current_version()
+            if self.version != current_version:
                 from packaging import version
-                logger.info(f"Config version mismatch detected: {self.version} != {get_current_version()}")
+                logger.info(f"New Config Found: {self.version} != {current_version}")
                 # Handle version mismatch
-                changed = False
                 if version.parse(self.version) < version.parse("2.18.0"):
-                    changed = True
                     # Example, doesn't need to be done
                     for profile in self.configs.values():
                         profile.obs.get_game_from_scene = True
@@ -877,10 +905,7 @@ class Config:
                         if profile.vad.selected_vad_model == WHISPER and profile.vad.backup_vad_model == SILERO:
                             profile.vad.backup_vad_model = OFF
 
-                if changed:
-                    self.save()
-
-        self.version = get_current_version()
+                self.save()
 
     def save(self):
         with open(get_config_path(), 'w') as file:
@@ -1160,6 +1185,11 @@ def get_config():
     # print(config_instance.get_config())
     return config_instance.get_config()
 
+def get_overlay_config():
+    global config_instance
+    if config_instance is None:
+        config_instance = load_config()
+    return config_instance.overlay
 
 def reload_config():
     global config_instance
@@ -1284,6 +1314,7 @@ class GsmAppState:
         self.recording_started_time = None
         self.current_srt = None
         self.srt_index = 1
+        self.current_audio_stream = None
 
 
 @dataclass_json
@@ -1297,10 +1328,11 @@ class AnkiUpdateResult:
     multi_line: bool = False
     video_in_anki: str = ''
     word_path: str = ''
+    word: str = ''
 
     @staticmethod
     def failure():
-        return AnkiUpdateResult(success=False, audio_in_anki='', screenshot_in_anki='', prev_screenshot_in_anki='', sentence_in_anki='', multi_line=False, video_in_anki='', word_path='')
+        return AnkiUpdateResult(success=False, audio_in_anki='', screenshot_in_anki='', prev_screenshot_in_anki='', sentence_in_anki='', multi_line=False, video_in_anki='', word_path='', word='')
 
 
 @dataclass_json
