@@ -15,10 +15,14 @@ import uuid
 import pytz
 from datetime import timedelta
 
+import regex
+
 from GameSentenceMiner.util.text_log import GameLine
 from GameSentenceMiner.util.configuration import get_stats_config, logger, is_dev
 import gzip
 
+# Matches any Unicode punctuation (\p{P}), symbol (\p{S}), or separator (\p{Z}); \p{Z} includes whitespace/separator chars
+punctuation_regex = regex.compile(r'[\p{P}\p{S}\p{Z}]')
 
 class SQLiteDB:
     """
@@ -136,7 +140,7 @@ class SQLiteDBTable:
         return cls.from_row(row) if row else None
 
     @classmethod
-    def from_row(cls: Type[T], row: Tuple) -> T:
+    def from_row(cls: Type[T], row: Tuple, clean_columns: list = []) -> T:
         if not row:
             return None
         obj = cls()
@@ -162,6 +166,9 @@ class SQLiteDBTable:
                 field = expected_fields[expected_pos]
                 field_type = cls._types[expected_pos]
                 
+                if field in clean_columns and isinstance(row_value, str):
+                    row_value = punctuation_regex.sub('', row_value).strip() 
+                
                 cls._set_field_value(obj, field, field_type, row_value, expected_pos == 0 and field == cls._pk)
                 
         except Exception as e:
@@ -451,9 +458,9 @@ class AIModelsTable(SQLiteDBTable):
 class GameLinesTable(SQLiteDBTable):
     _table = 'game_lines'
     _fields = ['game_name', 'line_text', 'screenshot_in_anki',
-               'audio_in_anki', 'screenshot_path', 'audio_path', 'replay_path', 'translation', 'timestamp', 'original_game_name']
+               'audio_in_anki', 'screenshot_path', 'audio_path', 'replay_path', 'translation', 'timestamp', 'original_game_name', 'game_id']
     _types = [str,  # Includes primary key type
-              str, str, str, str, str, str, str, str, float, str]
+              str, str, str, str, str, str, str, str, float, str, str]
     _pk = 'id'
     _auto_increment = False  # Use string IDs
 
@@ -468,7 +475,8 @@ class GameLinesTable(SQLiteDBTable):
                  audio_path: Optional[str] = None,
                  replay_path: Optional[str] = None,
                  translation: Optional[str] = None,
-                 original_game_name: Optional[str] = None):
+                 original_game_name: Optional[str] = None,
+                 game_id: Optional[str] = None):
         self.id = id
         self.game_name = game_name
         self.line_text = line_text
@@ -481,6 +489,13 @@ class GameLinesTable(SQLiteDBTable):
         self.replay_path = replay_path if replay_path is not None else ''
         self.translation = translation if translation is not None else ''
         self.original_game_name = original_game_name if original_game_name is not None else ''
+        self.game_id = game_id if game_id is not None else ''
+        
+    @classmethod
+    def all(cls, for_stats: bool = False) -> List['GameLinesTable']:
+        rows = cls._db.fetchall(f"SELECT * FROM {cls._table}")
+        clean_columns = ['line_text'] if for_stats else []
+        return [cls.from_row(row, clean_columns=clean_columns) for row in rows]
 
     @classmethod
     def get_all_lines_for_scene(cls, game_name: str) -> List['GameLinesTable']:
@@ -537,7 +552,7 @@ class GameLinesTable(SQLiteDBTable):
         )
         
     @classmethod
-    def get_lines_filtered_by_timestamp(cls, start: Optional[float] = None, end: Optional[float] = None) -> List['GameLinesTable']:
+    def get_lines_filtered_by_timestamp(cls, start: Optional[float] = None, end: Optional[float] = None, for_stats=False) -> List['GameLinesTable']:
         """
         Fetches all lines optionally filtered by start and end timestamps.
         If start or end is None, that bound is ignored.
@@ -563,8 +578,9 @@ class GameLinesTable(SQLiteDBTable):
 
         # Execute the query
         rows = cls._db.fetchall(query, tuple(params))
-        return [cls.from_row(row) for row in rows]
-        
+        clean_columns = ['line_text'] if for_stats else []
+        return [cls.from_row(row, clean_columns=clean_columns) for row in rows]
+
 class StatsRollupTable(SQLiteDBTable):
     _table = 'stats_rollup'
     _fields = ['date', 'games_played', 'lines_mined', 'anki_cards_created', 'time_spent_mining']
@@ -605,7 +621,7 @@ class StatsRollupTable(SQLiteDBTable):
         stats.anki_cards_created += anki_cards_created
         stats.time_spent_mining += time_spent_mining
         stats.save()
-        
+
 # Ensure database directory exists and return path
 def get_db_directory(test=False, delete_test=False) -> str:
     if platform == 'win32':  # Windows
@@ -659,7 +675,10 @@ if os.path.exists(db_path):
 
 gsm_db = SQLiteDB(db_path)
 
-for cls in [AIModelsTable, GameLinesTable]:
+# Import GamesTable after gsm_db is created to avoid circular import
+from GameSentenceMiner.util.games_table import GamesTable
+
+for cls in [AIModelsTable, GameLinesTable, GamesTable]:
     cls.set_db(gsm_db)
     # Uncomment to start fresh every time
     # cls.drop()
@@ -680,8 +699,7 @@ def check_and_run_migrations():
             # Copy and cast data from old column to new column
             GameLinesTable.alter_column_type('timestamp_old', 'timestamp', 'REAL')
             logger.info("Migrated 'timestamp' column to REAL type in GameLinesTable.")
-            
-            
+    
     migrate_timestamp()
         
 check_and_run_migrations()
